==> progamification-0.0.21.tar.gz: lib/src/services/gamification.service.dart <==
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/services/auth.service.dart';
import 'package:progamification/src/services/leaderboard.service.dart';
import 'package:progamification/src/services/pro_gamfication.service.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:progamification/src/services/user.service.dart';
import 'package:get/get.dart';

class GamificationService {
  static Future<void> init(String clientId, String clientSecret, String userId,
      String applicationId) async {
    Get.put<GamificationAuthService>(GamificationAuthService());
    Get.put<GamificationStorageService>(GamificationStorageService());
    Get.put<SasTokenService>(SasTokenService());
    GamificationStorageService.setString('userId', userId);
    GamificationStorageService.setString('applicationId', applicationId);
    bool access = await GamificationAuthService.checkAccess();
    if (!access) {
      await GamificationAuthService.init(clientId, clientSecret);
    }
    Get.put<LeaderBoardService>(LeaderBoardService());
    Get.put<UserService>(UserService());
    Get.put(LeaderBoardController());
  }

  static updateGameAction(String userId, String gameActionId,
      String correspondingUserId, String correspondingUserApplicationId) async {
    ProGamificationService().addPointsToUser({
      "userId": userId,
      "gameActionId": gameActionId,
      "correspondingUserId": correspondingUserId,
      "correspondingUserApplicationId": correspondingUserApplicationId
    });
  }
}

==> progamification-0.0.22.tar.gz: lib/src/services/gamification.service.dart <==
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/services/auth.service.dart';
import 'package:progamification/src/services/leaderboard.service.dart';
import 'package:progamification/src/services/pro_gamfication.service.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:progamification/src/services/user.service.dart';
import 'package:get/get.dart';

class GamificationService {
  static Future<void> init(String clientId, String clientSecret, String userId,
      String applicationId) async {
    Get.put<GamificationAuthService>(GamificationAuthService());
    Get.put<GamificationStorageService>(GamificationStorageService());
    Get.put<SasTokenService>(SasTokenService());
    GamificationStorageService.setString('userId', userId);
    GamificationStorageService.setString('applicationId', applicationId);
    bool access = await GamificationAuthService.checkAccess();
    if (!access) {
      await GamificationAuthService.init(clientId, clientSecret);
    }
    Get.put<LeaderBoardService>(LeaderBoardService());
    Get.put<UserService>(UserService());
    // Get.put(LeaderBoardController());
    Get.lazyPut(() => LeaderBoardController());
  }

  static updateGameAction(String userId, String gameActionId,
      String correspondingUserId, String correspondingUserApplicationId) async {
    ProGamificationService().addPointsToUser({
      "userId": userId,
      "gameActionId": gameActionId,
      "correspondingUserId": correspondingUserId,
      "correspondingUserApplicationId": correspondingUserApplicationId
    });
  }
}
